@@ -381,4 +381,15 @@ ships = {   582: 'Bantam',
     33691: 'Tayra Wiyrkomi Edition',
     33693: 'Mammoth Nefantar Edition',
     33695: 'Bestower Tash-Murkon Edition',
-    33697: 'Prospect'}
+    33697: 'Prospect',
+    33816: 'Garmur',
+    33818: 'Orthrus',
+    33820: 'Barghest',
+    33869: 'Brutix Serpentis Edition',
+    33871: 'Cyclone Thukker Tribe Edition',
+    33873: 'Ferox Guristas Edition',
+    33875: 'Prophecy Blood Raiders Edition',
+    33877: 'Catalyst Serpentis Edition',
+    33879: 'Coercer Blood Raiders Edition',
+    33881: 'Cormorant Guristas Edition',
+    33883: 'Thrasher Thukker Tribe Edition'}
